import chronoptics.tof as tof
import time

config = tof.ProcessingConfig()

camera = tof.KeaCamera(config, "202004a")
camera.setOnCameraProcessing(True)

cam_config = camera.getCameraConfig()
cam_config.setTriggerMode(tof.TriggerMode.SOFTWARE)
camera.setCameraConfig(cam_config)

tof.selectStreams(camera, [tof.FrameType.XYZ_BGR_I])
camera.start()

# Wait for the first frame to come through
while not camera.hasFrames():
    camera.softwareTrigger()

# Make sure there are no more triggered frames
time.sleep(0.5)
camera.clearBuffer()

start = time.time()

nr_of_triggers = 100
for i in range(nr_of_triggers):
    print(i)

    camera.softwareTrigger()
    camera.getFrames()

end = time.time()

total_time = end - start
time_per_trigger = total_time / 100

print(f"Latency {time_per_trigger * 1000:.0f}ms")
